@@ -77,7 +77,7 @@ def total_size(o, handlers={}):
 
 
 class DownloadVnException(Exception):
-    """An exception occurred while handling download or store. """
+    """An exception occurred while handling download or store."""
 
 
 class NotImplementedException(DownloadVnException):
@@ -151,25 +151,34 @@ class DownloadVn:
         i = 0
         if opt_params_iter is None:
             opt_params_iter = iter([None])
-        for opt_params in opt_params_iter:
-            i += 1
-            log_msg = _("Iteration {}, opt_params = {}").format(i, opt_params)
-            logger.debug(log_msg)
-            timing = perf_counter_ns()
-            items_dict = self._api_instance.api_list(opt_params=opt_params)
-            timing = (perf_counter_ns() - timing) / 1000
-            # Call backend to store generic log
+        try:
+            for opt_params in opt_params_iter:
+                i += 1
+                log_msg = _("Iteration {}, opt_params = {}").format(i, opt_params)
+                logger.debug(log_msg)
+                timing = perf_counter_ns()
+                items_dict = self._api_instance.api_list(opt_params=opt_params)
+                timing = (perf_counter_ns() - timing) / 1000
+                # Call backend to store generic log
+                self._backend.log(
+                    self._config.site,
+                    self._api_instance.controler,
+                    self._api_instance.transfer_errors,
+                    self._api_instance.http_status,
+                    log_msg,
+                    total_size(items_dict),
+                    timing,
+                )
+                # Call backend to store results
+                self._backend.store(self._api_instance.controler, str(i), items_dict)
+        except self._api_instance.HTTPError:
             self._backend.log(
                 self._config.site,
                 self._api_instance.controler,
                 self._api_instance.transfer_errors,
                 self._api_instance.http_status,
-                log_msg,
-                total_size(items_dict),
-                timing,
+                _("HTTP error during download"),
             )
-            # Call backend to store results
-            self._backend.store(self._api_instance.controler, str(i), items_dict)
 
         return None
 
@@ -243,37 +252,46 @@ class Fields(DownloadVn):
         i = 0
         if opt_params_iter is None:
             opt_params_iter = iter([None])
-        for opt_params in opt_params_iter:
-            i += 1
-            log_msg = _("Iteration {}, opt_params = {}").format(i, opt_params)
-            logger.debug(log_msg)
-            timing = perf_counter_ns()
-            items_dict = self._api_instance.api_list(opt_params=opt_params)
-            timing = (perf_counter_ns() - timing) / 1000
-            # Call backend to store generic log
+        try:
+            for opt_params in opt_params_iter:
+                i += 1
+                log_msg = _("Iteration {}, opt_params = {}").format(i, opt_params)
+                logger.debug(log_msg)
+                timing = perf_counter_ns()
+                items_dict = self._api_instance.api_list(opt_params=opt_params)
+                timing = (perf_counter_ns() - timing) / 1000
+                # Call backend to store generic log
+                self._backend.log(
+                    self._config.site,
+                    self._api_instance.controler,
+                    self._api_instance.transfer_errors,
+                    self._api_instance.http_status,
+                    log_msg,
+                    total_size(items_dict),
+                    timing,
+                )
+                # Call backend to store groups of fields
+                self._backend.store("field_groups", str(i), items_dict)
+
+                # Loop on field groups to get details
+                for field in items_dict["data"]:
+                    field_id = field["id"]
+                    field_details = self._api_instance.api_get(field_id)
+                    for detail in field_details["data"]:
+                        detail["group"] = field_id
+                    logger.debug(
+                        _("Details for field group %s = %s"), field_id, field_details
+                    )
+                    # Call backend to store groups of fields
+                    self._backend.store("field_details", str(i), field_details)
+        except self._api_instance.HTTPError:
             self._backend.log(
                 self._config.site,
                 self._api_instance.controler,
                 self._api_instance.transfer_errors,
                 self._api_instance.http_status,
-                log_msg,
-                total_size(items_dict),
-                timing,
+                _("HTTP error during download"),
             )
-            # Call backend to store groups of fields
-            self._backend.store("field_groups", str(i), items_dict)
-
-            # Loop on field groups to get details
-            for field in items_dict["data"]:
-                field_id = field["id"]
-                field_details = self._api_instance.api_get(field_id)
-                for detail in field_details["data"]:
-                    detail["group"] = field_id
-                logger.debug(
-                    _("Details for field group %s = %s"), field_id, field_details
-                )
-                # Call backend to store groups of fields
-                self._backend.store("field_details", str(i), field_details)
 
         return None
 
@@ -321,9 +339,7 @@ class LocalAdminUnits(DownloadVn):
                 q_param = {"id_canton": id_canton}
                 super().store([q_param])
         else:
-            logger.debug(
-                _("Getting all local_admin_units, using API list")
-            )
+            logger.debug(_("Getting all local_admin_units, using API list"))
             super().store()
 
 
@@ -347,7 +363,13 @@ class Observations(DownloadVn):
             max_requests,
             max_chunks,
         )
-        self._t_units = ReadPostgresql(self._config).read("territorial_units")
+        self._t_units = None
+        if self._config.db_enabled:
+            # Try to read from local database
+            self._t_units = ReadPostgresql(self._config).read("territorial_units")
+        if (self._t_units is None) or (len(self._t_units) == 0):
+            # No territorial_units available, read from API
+            self._t_units = [TerritorialUnitsAPI(self._config).api_list()["data"]]
         return None
 
     def _store_list(self, id_taxo_group, by_specie, short_version="1"):
@@ -377,76 +399,89 @@ class Observations(DownloadVn):
             taxo_groups = TaxoGroupsAPI(self._config).api_list()["data"]
         else:
             taxo_groups = [{"id": id_taxo_group, "access_mode": "full"}]
-        for taxo in taxo_groups:
-            if taxo["access_mode"] != "none":
-                id_taxo_group = taxo["id"]
-                self._backend.increment_log(
-                    self._config.site, id_taxo_group, datetime.now()
-                )
-                logger.info(
-                    _("Getting observations from taxo_group %s, in _store_list"),
-                    id_taxo_group,
-                )
-                if by_specie:
-                    species = SpeciesAPI(self._config).api_list(
-                        {"id_taxo_group": str(id_taxo_group)}
-                    )["data"]
-                    for specie in species:
-                        if specie["is_used"] == "1":
-                            logger.info(
-                                _("Getting observations from taxo_group %s, specie %s"),
-                                id_taxo_group,
-                                specie["id"],
-                            )
-                            timing = perf_counter_ns()
-                            items_dict = self._api_instance.api_list(
-                                id_taxo_group,
-                                id_species=specie["id"],
-                                short_version=short_version,
-                            )
-                            timing = (perf_counter_ns() - timing) / 1000
-                            # Call backend to store list by taxo_group, species log
-                            self._backend.log(
-                                self._config.site,
-                                self._api_instance.controler,
-                                self._api_instance.transfer_errors,
-                                self._api_instance.http_status,
-                                (
-                                    _("observations from taxo_group %s, species %s"),
+        try:
+            for taxo in taxo_groups:
+                if taxo["access_mode"] != "none":
+                    id_taxo_group = taxo["id"]
+                    self._backend.increment_log(
+                        self._config.site, id_taxo_group, datetime.now()
+                    )
+                    logger.info(
+                        _("Getting observations from taxo_group %s, in _store_list"),
+                        id_taxo_group,
+                    )
+                    if by_specie:
+                        species = SpeciesAPI(self._config).api_list(
+                            {"id_taxo_group": str(id_taxo_group)}
+                        )["data"]
+                        for specie in species:
+                            if specie["is_used"] == "1":
+                                logger.info(
+                                    _(
+                                        "Getting observations from taxo_group %s, specie %s"
+                                    ),
                                     id_taxo_group,
                                     specie["id"],
-                                ),
-                                total_size(items_dict),
-                                timing,
-                            )
-                            # Call backend to store results
-                            self._backend.store(
-                                self._api_instance.controler,
-                                str(id_taxo_group) + "_" + specie["id"],
-                                items_dict,
-                            )
-                else:
-                    timing = perf_counter_ns()
-                    items_dict = self._api_instance.api_list(
-                        id_taxo_group, short_version=short_version
-                    )
-                    timing = (perf_counter_ns() - timing) / 1000
-                    # Call backend to store list by taxo_group log
-                    self._backend.log(
-                        self._config.site,
-                        self._api_instance.controler,
-                        self._api_instance.transfer_errors,
-                        self._api_instance.http_status,
-                        (_("observations from taxo_group %s"), id_taxo_group),
-                        total_size(items_dict),
-                        timing,
-                    )
-                    # Call backend to store results
-                    self._backend.store(
-                        self._api_instance.controler,
-                        str(id_taxo_group) + "_1",
-                        items_dict,
-                    )
+                                )
+                                timing = perf_counter_ns()
+                                items_dict = self._api_instance.api_list(
+                                    id_taxo_group,
+                                    id_species=specie["id"],
+                                    short_version=short_version,
+                                )
+                                timing = (perf_counter_ns() - timing) / 1000
+                                # Call backend to store list by taxo_group, species log
+                                self._backend.log(
+                                    self._config.site,
+                                    self._api_instance.controler,
+                                    self._api_instance.transfer_errors,
+                                    self._api_instance.http_status,
+                                    (
+                                        _(
+                                            "observations from taxo_group %s, species %s"
+                                        ),
+                                        id_taxo_group,
+                                        specie["id"],
+                                    ),
+                                    total_size(items_dict),
+                                    timing,
+                                )
+                                # Call backend to store results
+                                self._backend.store(
+                                    self._api_instance.controler,
+                                    str(id_taxo_group) + "_" + specie["id"],
+                                    items_dict,
+                                )
+                    else:
+                        timing = perf_counter_ns()
+                        items_dict = self._api_instance.api_list(
+                            id_taxo_group, short_version=short_version
+                        )
+                        timing = (perf_counter_ns() - timing) / 1000
+                        # Call backend to store list by taxo_group log
+                        self._backend.log(
+                            self._config.site,
+                            self._api_instance.controler,
+                            self._api_instance.transfer_errors,
+                            self._api_instance.http_status,
+                            (_("observations from taxo_group %s"), id_taxo_group),
+                            total_size(items_dict),
+                            timing,
+                        )
+                        # Call backend to store results
+                        self._backend.store(
+                            self._api_instance.controler,
+                            str(id_taxo_group) + "_1",
+                            items_dict,
+                        )
+        except self._api_instance.HTTPError:
+            self._backend.log(
+                self._config.site,
+                self._api_instance.controler,
+                self._api_instance.transfer_errors,
+                self._api_instance.http_status,
+                _("HTTP error during download"),
+            )
 
         return None
 
@@ -479,117 +514,132 @@ class Observations(DownloadVn):
             taxo_groups = TaxoGroupsAPI(self._config).api_list()["data"]
         else:
             taxo_groups = [{"id": id_taxo_group, "access_mode": "full"}]
-        for taxo in taxo_groups:
-            if taxo["access_mode"] != "none":
-                id_taxo_group = taxo["id"]
-                logger.debug(
-                    _("Getting observations from taxo_group %s"),
-                    id_taxo_group,
-                )
+        try:
+            for taxo in taxo_groups:
+                if taxo["access_mode"] != "none":
+                    id_taxo_group = taxo["id"]
+                    logger.debug(
+                        _("Getting observations from taxo_group %s"),
+                        id_taxo_group,
+                    )
 
-                # Record end of download interval
-                if self._config.end_date is None:
-                    end_date = datetime.now()
-                else:
-                    end_date = self._config.end_date
-                since = self._backend.increment_get(self._config.site, id_taxo_group)
-                if since is None:
-                    since = end_date
-                self._backend.increment_log(self._config.site, id_taxo_group, since)
-
-                # When to start download interval
-                start_date = end_date
-                min_date = (
-                    datetime(1900, 1, 1)
-                    if self._config.start_date is None
-                    else self._config.start_date
-                )
-                seq = 1
-                pid = PID(
-                    kp=self._config.tuning_pid_kp,
-                    ki=self._config.tuning_pid_ki,
-                    kd=self._config.tuning_pid_kd,
-                    setpoint=self._config.tuning_pid_setpoint,
-                    output_limits=(
-                        self._config.tuning_pid_limit_min,
-                        self._config.tuning_pid_limit_max,
-                    ),
-                )
-                delta_days = self._config.tuning_pid_delta_days
-                while start_date > min_date:
-                    nb_obs = 0
-                    start_date = end_date - timedelta(days=delta_days)
-                    q_param = {
-                        "period_choice": "range",
-                        "date_from": start_date.strftime("%d.%m.%Y"),
-                        "date_to": end_date.strftime("%d.%m.%Y"),
-                        "species_choice": "all",
-                        "taxonomic_group": taxo["id"],
-                    }
-                    if self._config._type_date is not None:
-                        if self._config._type_date == "entry":
-                            q_param["entry_date"] = "1"
-                        else:
-                            q_param["entry_date"] = "0"
-                    if territorial_unit_ids is None or len(territorial_unit_ids) == 0:
-                        t_us = self._t_units
+                    # Record end of download interval
+                    if self._config.end_date is None:
+                        end_date = datetime.now()
                     else:
-                        t_us = [
-                            u
-                            for u in self._t_units
-                            if u[0]["short_name"] in territorial_unit_ids
-                        ]
-                    for t_u in t_us:
-                        logger.debug(
-                            _(
-                                "Getting observations from territorial_unit %s, using API search"
-                            ),
-                            t_u[0]["name"],
-                        )
-                        q_param["location_choice"] = "territorial_unit"
-                        q_param["territorial_unit_ids"] = [
-                            t_u[0]["id_country"] + t_u[0]["short_name"]
-                        ]
+                        end_date = self._config.end_date
+                    since = self._backend.increment_get(
+                        self._config.site, id_taxo_group
+                    )
+                    if since is None:
+                        since = end_date
+                    self._backend.increment_log(self._config.site, id_taxo_group, since)
 
-                        timing = perf_counter_ns()
-                        items_dict = self._api_instance.api_search(
-                            q_param, short_version=short_version
-                        )
-                        timing = (perf_counter_ns() - timing) / 1000
+                    # When to start download interval
+                    start_date = end_date
+                    min_date = (
+                        datetime(1900, 1, 1)
+                        if self._config.start_date is None
+                        else self._config.start_date
+                    )
+                    seq = 1
+                    pid = PID(
+                        kp=self._config.tuning_pid_kp,
+                        ki=self._config.tuning_pid_ki,
+                        kd=self._config.tuning_pid_kd,
+                        setpoint=self._config.tuning_pid_setpoint,
+                        output_limits=(
+                            self._config.tuning_pid_limit_min,
+                            self._config.tuning_pid_limit_max,
+                        ),
+                    )
+                    delta_days = self._config.tuning_pid_delta_days
+                    while start_date > min_date:
+                        nb_obs = 0
+                        start_date = end_date - timedelta(days=delta_days)
+                        q_param = {
+                            "period_choice": "range",
+                            "date_from": start_date.strftime("%d.%m.%Y"),
+                            "date_to": end_date.strftime("%d.%m.%Y"),
+                            "species_choice": "all",
+                            "taxonomic_group": taxo["id"],
+                        }
+                        if self._config._type_date is not None:
+                            if self._config._type_date == "entry":
+                                q_param["entry_date"] = "1"
+                            else:
+                                q_param["entry_date"] = "0"
+                        if (
+                            territorial_unit_ids is None
+                            or len(territorial_unit_ids) == 0
+                        ):
+                            t_us = self._t_units
+                        else:
+                            t_us = [
+                                u
+                                for u in self._t_units
+                                if u[0]["short_name"] in territorial_unit_ids
+                            ]
+                        for t_u in t_us:
+                            logger.debug(
+                                _(
+                                    "Getting observations from territorial_unit %s, using API search"
+                                ),
+                                t_u[0]["name"],
+                            )
+                            q_param["location_choice"] = "territorial_unit"
+                            q_param["territorial_unit_ids"] = [
+                                t_u[0]["id_country"] + t_u[0]["short_name"]
+                            ]
+
+                            timing = perf_counter_ns()
+                            items_dict = self._api_instance.api_search(
+                                q_param, short_version=short_version
+                            )
+                            timing = (perf_counter_ns() - timing) / 1000
+
+                            # Call backend to store results
+                            nb_o = self._backend.store(
+                                self._api_instance.controler,
+                                str(id_taxo_group) + "_" + str(seq),
+                                items_dict,
+                            )
+                            # Throttle on max size downloaded during each interval
+                            nb_obs = max(nb_o, nb_obs)
+                            log_msg = _(
+                                "{} => Iter: {}, {} obs, taxo_group: {}, territorial_unit: {}, date: {}, interval: {}"
+                            ).format(
+                                self._config.site,
+                                seq,
+                                nb_o,
+                                id_taxo_group,
+                                t_u[0]["short_name"],
+                                start_date.strftime("%d/%m/%Y"),
+                                str(delta_days),
+                            )
+                            # Call backend to store log
+                            self._backend.log(
+                                self._config.site,
+                                self._api_instance.controler,
+                                self._api_instance.transfer_errors,
+                                self._api_instance.http_status,
+                                log_msg,
+                                total_size(items_dict),
+                                timing,
+                            )
+                            logger.info(log_msg)
+                        seq += 1
+                        end_date = start_date
+                        delta_days = int(pid(nb_obs))
+        except self._api_instance.HTTPError:
+            self._backend.log(
+                self._config.site,
+                self._api_instance.controler,
+                self._api_instance.transfer_errors,
+                self._api_instance.http_status,
+                _("HTTP error during download"),
+            )
 
-                        # Call backend to store results
-                        nb_o = self._backend.store(
-                            self._api_instance.controler,
-                            str(id_taxo_group) + "_" + str(seq),
-                            items_dict,
-                        )
-                        # Throttle on max size downloaded during each interval
-                        nb_obs = max(nb_o, nb_obs)
-                        log_msg = _(
-                            "{} => Iter: {}, {} obs, taxo_group: {}, territorial_unit: {}, date: {}, interval: {}"
-                        ).format(
-                            self._config.site,
-                            seq,
-                            nb_o,
-                            id_taxo_group,
-                            t_u[0]["short_name"],
-                            start_date.strftime("%d/%m/%Y"),
-                            str(delta_days),
-                        )
-                        # Call backend to store log
-                        self._backend.log(
-                            self._config.site,
-                            self._api_instance.controler,
-                            self._api_instance.transfer_errors,
-                            self._api_instance.http_status,
-                            log_msg,
-                            total_size(items_dict),
-                            timing,
-                        )
-                        logger.info(log_msg)
-                    seq += 1
-                    end_date = start_date
-                    delta_days = int(pid(nb_obs))
         return None
 
     def _list_taxo_groups(self, id_taxo_group, taxo_groups_ex=None):
@@ -721,7 +771,7 @@ class Observations(DownloadVn):
                     _("Getting updates for taxo_group %s since %s"), taxo, since
                 )
                 items_dict = self._api_instance.api_diff(
-                    taxo, since, modification_type="only_modified"
+                    taxo, since, modification_type="all"
                 )
 
                 # List by processing type
@@ -751,50 +801,60 @@ class Observations(DownloadVn):
                 logger.error(
                     _("No date found for last download, increment not performed")
                 )
-            # print(updated)
 
             # Process updates
-            if len(updated) > 0:
-                log_msg = _("Creating or updating {} observations").format(len(updated))
-                logger.debug(log_msg)
-                # Update backend store, in chunks
-                for i in range(
-                    (len(updated) + self._config.tuning_max_list_length - 1)
-                    // self._config.tuning_max_list_length
-                ):
-                    s_list = ",".join(
+            try:
+                if len(updated) > 0:
+                    logger.debug(
+                        _("Creating or updating %d observations"), len(updated)
+                    )
+                    # Update backend store, in chunks
+                    for i in range(
+                        (len(updated) + self._config.tuning_max_list_length - 1)
+                        // self._config.tuning_max_list_length
+                    ):
+                        s_list = ",".join(
                             updated[
                                 i
                                 * self._config.tuning_max_list_length : (i + 1)
                                 * self._config.tuning_max_list_length
                             ]
                         )
-                    logger.debug(_("Updating slice %s"), s_list)
-                    timing = perf_counter_ns()
-                    items_dict = self._api_instance.api_list(
-                        taxo,
-                        id_sightings_list=s_list,
-                        short_version=short_version,
-                    )
-                    timing = (perf_counter_ns() - timing) / 1000
+                        logger.debug(_("Updating slice %s"), s_list)
+                        timing = perf_counter_ns()
+                        items_dict = self._api_instance.api_list(
+                            taxo,
+                            id_sightings_list=s_list,
+                            short_version=short_version,
+                        )
+                        timing = (perf_counter_ns() - timing) / 1000
 
-                    # Call backend to store results
-                    self._backend.store(
-                        self._api_instance.controler,
-                        str(id_taxo_group) + "_upd_" + str(i),
-                        items_dict,
-                    )
+                        # Call backend to store results
+                        self._backend.store(
+                            self._api_instance.controler,
+                            str(id_taxo_group) + "_upd_" + str(i),
+                            items_dict,
+                        )
 
-                    # Call backend to store log
-                    self._backend.log(
-                        self._config.site,
-                        self._api_instance.controler,
-                        self._api_instance.transfer_errors,
-                        self._api_instance.http_status,
-                        log_msg,
-                        total_size(items_dict),
-                        timing,
-                    )
+                        # Call backend to store log
+                        self._backend.log(
+                            self._config.site,
+                            self._api_instance.controler,
+                            self._api_instance.transfer_errors,
+                            self._api_instance.http_status,
+                            _("Creating or updating %d observations")
+                            % (s_list.count(",") + 1),
+                            total_size(items_dict),
+                            timing,
+                        )
+            except self._api_instance.HTTPError:
+                self._backend.log(
+                    self._config.site,
+                    self._api_instance.controler,
+                    self._api_instance.transfer_errors,
+                    self._api_instance.http_status,
+                    _("HTTP error during download"),
+                )
 
             # Process deletes
             if len(deleted) > 0:
@@ -825,6 +885,7 @@ class Places(DownloadVn):
 
     Methods
     - store               - Download and store to json
+    - update              - Retrieve list of updates, then and update or delete places
 
     """
 
@@ -834,7 +895,17 @@ class Places(DownloadVn):
         super().__init__(
             config, PlacesAPI(config), backend, max_retry, max_requests, max_chunks
         )
-        self._l_a_units = ReadPostgresql(self._config).read("local_admin_units")
+        self._place_id = (
+            -1
+        )  # Integer index, to comply with taxo_groups, for increment log
+        self._l_a_units = None
+        if self._config.db_enabled:
+            # Try to read from local database
+            self._l_a_units = ReadPostgresql(self._config).read("local_admin_units")
+        if (self._l_a_units is None) or (len(self._l_a_units) == 0):
+            # No local_admin_units available, read from API
+            self._l_a_units = [LocalAdminUnitsAPI(self._config).api_list()["data"]]
+
         return None
 
     def store(
@@ -850,7 +921,8 @@ class Places(DownloadVn):
         territorial_unit_ids : list
             List of territorial_units to include in storage.
         """
-        if territorial_unit_ids is not None:
+        self._backend.increment_log(self._config.site, self._place_id, datetime.now())
+        if territorial_unit_ids is not None and len(territorial_unit_ids) > 0:
             # Get local_admin_units
             for id_canton in territorial_unit_ids:
                 # Loop on local_admin_units of the territorial_unit
@@ -869,6 +941,108 @@ class Places(DownloadVn):
             logger.debug(_("Getting places, using API list"))
             super().store()
 
+    def update(self, territorial_unit_ids=None, since=None):
+        """Download increment from VN by API and store json to file.
+
+        Gets previous update date from database and updates since then.
+        Calls  biolovision_api, finds if update or delete.
+        If update, get full place and store to db.
+        If delete, delete from db.
+
+        Parameters
+        ----------
+        territorial_unit_ids : str or None
+            If not None, territorial_unit to be downloaded.
+        since : str or None
+            If None, updates since last download
+            Or if provided, updates since that given date.
+
+        """
+        updated = list()
+        deleted = list()
+        if since is None:
+            since = self._backend.increment_get(self._config.site, self._place_id)
+        if since is not None:
+            # Valid since date provided or found in database
+            self._backend.increment_log(
+                self._config.site, self._place_id, datetime.now()
+            )
+            logger.info(_("Getting updates for places since %s"), since)
+            items_dict = self._api_instance.api_diff(since, modification_type="all")
+
+            # List by processing type
+            for item in items_dict:
+                logger.debug(
+                    _("Place %s was %s"),
+                    item["id_place"],
+                    item["modification_type"],
+                )
+                if item["modification_type"] == "updated":
+                    updated.append(item["id_place"])
+                elif item["modification_type"] == "deleted":
+                    deleted.append(item["id_place"])
+                else:
+                    logger.error(
+                        _("Observation %s has unknown processing %s"),
+                        item["id_universal"],
+                        item["modification_type"],
+                    )
+                    raise NotImplementedException
+            logger.info(
+                _("Received %d updated and %d deleted items"),
+                len(updated),
+                len(deleted),
+            )
+        else:
+            logger.error(_("No date found for last download, increment not performed"))
+
+        # Process updates
+        if len(updated) > 0:
+            logger.debug(_("Creating or updating %d places"), len(updated))
+            # # Update backend store, in chunks
+            # for i in range(
+            #     (len(updated) + self._config.tuning_max_list_length - 1)
+            #     // self._config.tuning_max_list_length
+            # ):
+            #     s_list = ",".join(
+            #         updated[
+            #             i
+            #             * self._config.tuning_max_list_length : (i + 1)
+            #             * self._config.tuning_max_list_length
+            #         ]
+            #     )
+            #     logger.debug(_("Updating slice %s"), s_list)
+            #     timing = perf_counter_ns()
+            #     items_dict = self._api_instance.api_list(
+            #         taxo,
+            #         id_sightings_list=s_list,
+            #         short_version=short_version,
+            #     )
+            #     timing = (perf_counter_ns() - timing) / 1000
+
+            #     # Call backend to store results
+            #     self._backend.store(
+            #         self._api_instance.controler,
+            #         str(id_taxo_group) + "_upd_" + str(i),
+            #         items_dict,
+            #     )
+
+            #     # Call backend to store log
+            #     self._backend.log(
+            #         self._config.site,
+            #         self._api_instance.controler,
+            #         self._api_instance.transfer_errors,
+            #         self._api_instance.http_status,
+            #         _("Creating or updating %d observations")
+            #         % (s_list.count(",") + 1),
+            #         total_size(items_dict),
+            #         timing,
+            #     )
+
+        # Process deletes
+        if len(deleted) > 0:
+            self._backend.delete_place(deleted)
+
 
 class Species(DownloadVn):
     """Implement store from species controler.
