@@ -11,35 +11,38 @@ Properties
 
 """
 import logging
-from datetime import datetime, date
-# from uuid import uuid4
+from datetime import date
 
+from psycopg2.extensions import ISOLATION_LEVEL_AUTOCOMMIT
 from pyproj import Transformer
 from sqlalchemy import (
     Column,
     DateTime,
     Integer,
+    BigInteger,
     MetaData,
     PrimaryKeyConstraint,
     String,
     Table,
     create_engine,
+    exc,
     func,
     select,
 )
-from sqlalchemy.dialects.postgresql import ARRAY, JSONB, insert
+from sqlalchemy.dialects.postgresql import JSONB, insert
 from sqlalchemy.engine.url import URL
 from sqlalchemy.sql import and_
 
-from psycopg2.extensions import ISOLATION_LEVEL_AUTOCOMMIT
-
 from . import _, __version__
 
+# from uuid import uuid4
+
+
 logger = logging.getLogger("transfer_vn.store_postgresql")
 
 
 class StorePostgresqlException(Exception):
-    """An exception occurred while handling download or store. """
+    """An exception occurred while handling download or store."""
 
 
 class ObservationItem:
@@ -200,6 +203,8 @@ class PostgresqlUtils:
             Column("error_count", Integer, index=True),
             Column("http_status", Integer, index=True),
             Column("comment", String),
+            Column("length", Integer, index=True),
+            Column("duration", BigInteger, index=True),
         )
         return None
 
@@ -300,7 +305,7 @@ class PostgresqlUtils:
             Column("site", String, nullable=False),
             Column("item", JSONB, nullable=False),
             Column("update_ts", Integer, nullable=False),
-            Column("id_form_universal", String),
+            Column("id_form_universal", String, index=True),
             PrimaryKeyConstraint("id", "site", name="observations_json_pk"),
         )
         return None
@@ -475,9 +480,12 @@ class PostgresqlUtils:
             text = "DROP DATABASE IF EXISTS {}".format(self._config.db_name)
             logger.debug(_("Dropping database: %s"), text)
             conn.execute(text)
-            text = "DROP ROLE IF EXISTS {}".format(self._config.db_group)
-            logger.debug(_("Dropping role: %s"), text)
-            conn.execute(text)
+            try:
+                text = "DROP ROLE IF EXISTS {}".format(self._config.db_group)
+                logger.debug(_("Dropping role: %s"), text)
+                conn.execute(text)
+            except exc.SQLAlchemyError as e:
+                logger.warning(_("Error %s ignored when dropping role"), repr(e))
 
             conn.close()
             db.dispose()
@@ -789,10 +797,10 @@ class ReadPostgresql(Postgresql):
             self._config.site,
         )
         metadata = self._table_defs[controler]["metadata"]
-        stmt = select([metadata.c.item]).where(
-            metadata.c.site == self._config.site)
+        stmt = select([metadata.c.item]).where(metadata.c.site == self._config.site)
         return self._conn.execute(stmt).fetchall()
 
+
 class StorePostgresql(Postgresql):
     """Provides store to Postgresql database method."""
 
@@ -1178,7 +1186,7 @@ class StorePostgresql(Postgresql):
         Parameters
         ----------
         obs_list : list
-            Data returned from API call.
+            List of observations id to be deleted.
 
         Returns
         -------
@@ -1206,7 +1214,50 @@ class StorePostgresql(Postgresql):
 
         return nb_delete
 
-    def log(self, site, controler, error_count=0, http_status=0, comment=""):
+    def delete_place(self, place_list):
+        """Delete places stored in database.
+
+        Parameters
+        ----------
+        place_list : list
+            List of place id to be deleted.
+
+        Returns
+        -------
+        int
+            Count of items deleted.
+        """
+        nb_delete = 0
+        # Store to database, if enabled
+        if self._config.db_enabled:
+            logger.info(_("Deleting %d places from database"), len(place_list))
+            nb_delete = 0
+            for obs in place_list:
+                nd = self._conn.execute(
+                    self._table_defs["places"]["metadata"]
+                    .delete()
+                    .where(
+                        and_(
+                            self._table_defs["places"]["metadata"].c.id == obs,
+                            self._table_defs["places"]["metadata"].c.site
+                            == self._config.site,
+                        )
+                    )
+                )
+                nb_delete += nd.rowcount
+
+        return nb_delete
+
+    def log(
+        self,
+        site,
+        controler,
+        error_count=0,
+        http_status=0,
+        comment="",
+        length=0,
+        duration=0,
+    ):
         """Write download log entries to database.
 
         Parameters
@@ -1221,6 +1272,10 @@ class StorePostgresql(Postgresql):
             HTTP status of latest download.
         comment : str
             Optional comment, in free text.
+        length : integer
+            Optional length of data transfer
+        duration : integer
+            Optional duration of data transfer, in ms
         """
         # Store to database, if enabled
         if self._config.db_enabled:
@@ -1233,6 +1288,8 @@ class StorePostgresql(Postgresql):
                 error_count=error_count,
                 http_status=http_status,
                 comment=comment,
+                length=length,
+                duration=duration,
             )
             self._conn.execute(stmt)
 
