@@ -18,11 +18,6 @@ from pathlib import Path
 import pkg_resources
 import psutil
 import requests
-from bs4 import BeautifulSoup
-from jinja2 import Environment, PackageLoader
-from pytz import utc
-from sqlalchemy.engine.url import URL
-
 import yappi
 from apscheduler.events import EVENT_JOB_ERROR, EVENT_JOB_EXECUTED, EVENT_JOB_SUBMITTED
 from apscheduler.executors.pool import ProcessPoolExecutor
@@ -30,6 +25,12 @@ from apscheduler.jobstores.memory import MemoryJobStore
 from apscheduler.jobstores.sqlalchemy import SQLAlchemyJobStore
 from apscheduler.schedulers import SchedulerNotRunningError
 from apscheduler.schedulers.background import BackgroundScheduler
+from bs4 import BeautifulSoup
+from jinja2 import Environment, PackageLoader
+from pytz import utc
+from strictyaml import YAMLValidationError
+from tabulate import tabulate
+
 from export_vn.download_vn import (
     Entities,
     Families,
@@ -47,8 +48,6 @@ from export_vn.evnconf import EvnConf
 from export_vn.store_all import StoreAll
 from export_vn.store_file import StoreFile
 from export_vn.store_postgresql import PostgresqlUtils, StorePostgresql
-from strictyaml import YAMLValidationError
-from tabulate import tabulate
 
 from . import _, __version__
 
@@ -65,6 +64,7 @@ CTRL_DEFS = {
     "territorial_units": TerritorialUnits,
     "validations": Validations,
 }
+
 logger = logging.getLogger("transfer_vn")
 
 
@@ -288,6 +288,11 @@ def arguments(args):
     parser.add_argument(
         "--db_create", help=_("Create database and roles"), action="store_true"
     )
+    parser.add_argument(
+        "--db_migrate",
+        help=_("Migrate database to current version"),
+        action="store_true",
+    )
     parser.add_argument(
         "--json_tables_create",
         help=_("Create or recreate json tables"),
@@ -330,7 +335,6 @@ def arguments(args):
 
 def init(file: str):
     """Copy template YAML file to home directory."""
-    logger = logging.getLogger("transfer_vn")
     yaml_src = pkg_resources.resource_filename(__name__, "data/evn_template.yaml")
     yaml_dst = str(Path.home() / file)
     logger.info(_("Creating YAML configuration file %s, from %s"), yaml_dst, yaml_src)
@@ -340,7 +344,6 @@ def init(file: str):
 
 def col_table_create(cfg, sql_quiet, client_min_message):
     """Create the column based tables, by running psql script."""
-    logger = logging.getLogger("transfer_vn")
     logger.debug(_("Creating SQL file from template"))
     env = Environment(
         loader=PackageLoader("export_vn", "sql"),
@@ -377,9 +380,35 @@ def col_table_create(cfg, sql_quiet, client_min_message):
     return None
 
 
+def migrate(cfg, sql_quiet, client_min_message):
+    """Create the column based tables, by running psql script."""
+    logger.debug(_("Migrating database to current version"))
+    Environment(
+        loader=PackageLoader("export_vn", "sql"),
+        keep_trailing_newline=True,
+    )
+    try:
+        subprocess.run(
+            "alembic -x db_schema_import=import -x db_url=postgresql://"
+            + cfg.db_user
+            + ":"
+            + cfg.db_pw
+            + "@"
+            + cfg.db_host
+            + "/"
+            + cfg.db_name
+            + "--config src/alembic.ini upgrade head",
+            check=True,
+            shell=True,
+        )
+    except subprocess.CalledProcessError as err:  # pragma: no cover
+        logger.error(err)
+
+    return None
+
+
 def full_download_1(ctrl, cfg_crtl_list, cfg):
     """Downloads from a single controler."""
-    logger = logging.getLogger("transfer_vn")
     logger.debug(_("Enter full_download_1: %s"), ctrl.__name__)
     with StorePostgresql(cfg) as store_pg, StoreFile(cfg) as store_f:
         store_all = StoreAll(cfg, db_backend=store_pg, file_backend=store_f)
@@ -402,9 +431,13 @@ def full_download_1(ctrl, cfg_crtl_list, cfg):
                     territorial_unit_ids=cfg.territorial_unit_ids,
                     short_version=(1 if cfg.json_format == "short" else 0),
                 )
-            elif (downloader.name == "local_admin_units") or (downloader.name == "places"):
+            elif (downloader.name == "local_admin_units") or (
+                downloader.name == "places"
+            ):
                 logger.info(
-                    _("%s => Included territorial_unit_ids: %s"), cfg.site, cfg.territorial_unit_ids
+                    _("%s => Included territorial_unit_ids: %s"),
+                    cfg.site,
+                    cfg.territorial_unit_ids,
                 )
                 downloader.store(
                     territorial_unit_ids=cfg.territorial_unit_ids,
@@ -419,21 +452,20 @@ def full_download_1(ctrl, cfg_crtl_list, cfg):
 def full_download(cfg_ctrl):
     """Performs a full download of all sites and controlers,
     based on configuration file."""
-    logger = logging.getLogger("transfer_vn")
     cfg_crtl_list = cfg_ctrl.ctrl_list
     cfg_site_list = cfg_ctrl.site_list
     cfg = list(cfg_site_list.values())[0]
 
     logger.info(_("Defining full download jobs"))
-    db_url = {
-        "drivername": "postgresql+psycopg2",
-        "username": cfg.db_user,
-        "password": cfg.db_pw,
-        "host": cfg.db_host,
-        "port": cfg.db_port,
-        "database": "postgres",
-    }
-    jobs_o = Jobs(url=URL(**db_url), nb_executors=cfg.tuning_sched_executors)
+    # db_url = {
+    #     "drivername": "postgresql+psycopg2",
+    #     "username": cfg.db_user,
+    #     "password": cfg.db_pw,
+    #     "host": cfg.db_host,
+    #     "port": cfg.db_port,
+    #     "database": "postgres",
+    # }
+    jobs_o = Jobs(nb_executors=cfg.tuning_sched_executors)
     with jobs_o as jobs:
         # Cleanup any existing job
         jobs.start(paused=True)
@@ -489,7 +521,6 @@ def full_download(cfg_ctrl):
 
 def increment_download_1(ctrl, cfg_crtl_list, cfg):
     """Download incremental updates from one site."""
-    logger = logging.getLogger("transfer_vn")
     logger.debug(_("Enter increment_download_1: %s"), ctrl.__name__)
     with StorePostgresql(cfg) as store_pg, StoreFile(cfg) as store_f:
         store_all = StoreAll(cfg, db_backend=store_pg, file_backend=store_f)
@@ -505,9 +536,20 @@ def increment_download_1(ctrl, cfg_crtl_list, cfg):
                     _("%s => Excluded taxo_groups: %s"), cfg.site, cfg.taxo_exclude
                 )
                 downloader.update(taxo_groups_ex=cfg.taxo_exclude)
-            elif (downloader.name == "local_admin_units") or (downloader.name == "places"):
+            elif downloader.name == "places":
                 logger.info(
-                    _("%s => Included territorial_unit_ids: %s"), cfg.site, cfg.territorial_unit_ids
+                    _("%s => Included territorial_unit_ids: %s"),
+                    cfg.site,
+                    cfg.territorial_unit_ids,
+                )
+                downloader.update(
+                    territorial_unit_ids=cfg.territorial_unit_ids,
+                )
+            elif downloader.name == "local_admin_units":
+                logger.info(
+                    _("%s => Included territorial_unit_ids: %s"),
+                    cfg.site,
+                    cfg.territorial_unit_ids,
                 )
                 downloader.store(
                     territorial_unit_ids=cfg.territorial_unit_ids,
@@ -522,21 +564,20 @@ def increment_download_1(ctrl, cfg_crtl_list, cfg):
 def increment_download(cfg_ctrl):
     """Performs an incremental download of observations from all sites
     and controlers, based on configuration file."""
-    logger = logging.getLogger("transfer_vn")
     cfg_site_list = cfg_ctrl.site_list
     cfg = list(cfg_site_list.values())[0]
 
     logger.info(_("Starting incremental download jobs"))
-    db_url = {
-        "drivername": "postgresql+psycopg2",
-        "username": cfg.db_user,
-        "password": cfg.db_pw,
-        "host": cfg.db_host,
-        "port": cfg.db_port,
-        "database": "postgres",
-    }
+    # db_url = {
+    #     "drivername": "postgresql+psycopg2",
+    #     "username": cfg.db_user,
+    #     "password": cfg.db_pw,
+    #     "host": cfg.db_host,
+    #     "port": cfg.db_port,
+    #     "database": "postgres",
+    # }
 
-    jobs_o = Jobs(url=URL(**db_url), nb_executors=cfg.tuning_sched_executors)
+    jobs_o = Jobs(nb_executors=cfg.tuning_sched_executors)
     with jobs_o as jobs:
         # Start scheduler and wait for jobs to finish
         jobs.start()
@@ -551,21 +592,20 @@ def increment_download(cfg_ctrl):
 def increment_schedule(cfg_ctrl):
     """Creates or modify the incremental download schedule,
     based on YAML controler configuration."""
-    logger = logging.getLogger("transfer_vn")
     cfg_crtl_list = cfg_ctrl.ctrl_list
     cfg_site_list = cfg_ctrl.site_list
     cfg = list(cfg_site_list.values())[0]
 
     logger.info(_("Defining incremental download jobs"))
-    db_url = {
-        "drivername": "postgresql+psycopg2",
-        "username": cfg.db_user,
-        "password": cfg.db_pw,
-        "host": cfg.db_host,
-        "port": cfg.db_port,
-        "database": "postgres",
-    }
-    jobs = Jobs(url=URL(**db_url), nb_executors=cfg.tuning_sched_executors)
+    # db_url = {
+    #     "drivername": "postgresql+psycopg2",
+    #     "username": cfg.db_user,
+    #     "password": cfg.db_pw,
+    #     "host": cfg.db_host,
+    #     "port": cfg.db_port,
+    #     "database": "postgres",
+    # }
+    jobs = Jobs(nb_executors=cfg.tuning_sched_executors)
     # Looping on sites
     for site, cfg in cfg_site_list.items():
         if cfg.enabled:
@@ -600,28 +640,26 @@ def increment_schedule(cfg_ctrl):
 
 def status(cfg_ctrl):
     """Print download status, using logger."""
-    logger = logging.getLogger("transfer_vn")
     cfg_site_list = cfg_ctrl.site_list
     cfg_site_list = cfg_ctrl.site_list
     cfg = list(cfg_site_list.values())[0]
 
     logger.info(_("Download jobs status"))
-    db_url = {
-        "drivername": "postgresql+psycopg2",
-        "username": cfg.db_user,
-        "password": cfg.db_pw,
-        "host": cfg.db_host,
-        "port": cfg.db_port,
-        "database": "postgres",
-    }
-    jobs = Jobs(url=URL(**db_url), nb_executors=cfg.tuning_sched_executors)
+    # db_url = {
+    #     "drivername": "postgresql+psycopg2",
+    #     "username": cfg.db_user,
+    #     "password": cfg.db_pw,
+    #     "host": cfg.db_host,
+    #     "port": cfg.db_port,
+    #     "database": "postgres",
+    # }
+    jobs = Jobs(nb_executors=cfg.tuning_sched_executors)
     jobs.start(paused=True)
     jobs.print_jobs()
 
 
 def count_observations(cfg_ctrl):
     """Count observations by site and taxo_group."""
-    logger = logging.getLogger("transfer_vn")
     cfg_site_list = cfg_ctrl.site_list
 
     col_counts = None
@@ -691,8 +729,6 @@ def main(args):
     # Create $HOME/tmp directory if it does not exist
     (Path.home() / "tmp").mkdir(exist_ok=True)
 
-    # Define logger format and handlers
-    logger = logging.getLogger("transfer_vn")
     # create file handler which logs even debug messages
     fh = TimedRotatingFileHandler(
         str(Path.home()) + "/tmp/transfer_vn.log",
@@ -767,6 +803,10 @@ def main(args):
         logger.info(_("Create database and roles"))
         manage_pg.create_database()
 
+    if args.db_migrate:
+        logger.info(_("Migrating database to current version"))
+        migrate(cfg, sql_quiet, client_min_message)
+
     if args.json_tables_create:
         logger.info(_("Create, if not exists, json tables"))
         manage_pg.create_json_tables()
